==> kschreiber_1_07.tar.gz: kschreiber_1_07/kschreiber.h <==
/***************************************************************************
 *   Copyright (C) 2009 by Andreas Lindenau   *
 *   DL4JAL@darc.de   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/


#ifndef kschreiber_H
#define kschreiber_H

#include <QMainWindow>
#include <QCloseEvent>
#include <QLineEdit>
#include <QLabel>
#include <QCheckBox>
#include <QGroupBox>
#include <QRadioButton>
#include <QProgressDialog>
#include <QSpinBox>
#include <QPushButton>
#include <QTimer>

#include "wdisplay.h"

#ifdef Q_WS_WIN
#include "win_modem.h"
#else
#include "lin_modem.h"
#endif



class QAction;
class QMenu;
class QTabWidget;
class QWidget;
class QTextEdit;
class QComboBox;

enum ehalbleitertyp {enpn, epnp, enmosfet, epmosfet, enjfet, epjfet, ediode};
enum ekurventyp {eausgang, eeingang};

class kschreiber:public QMainWindow
{
      Q_OBJECT

public:
  kschreiber();
  ~kschreiber();

protected:
  void closeEvent(QCloseEvent *event);
  virtual void resizeEvent( QResizeEvent *);
  virtual void repaintEvent( QPaintEvent *);

private slots:
  void about();
  void rs232einstellen();
  void setAText(QString);
  void kennlausgang();
  void kennleingang();
  void setnpn();
  void setpnp();
  void setnmosfet();
  void setpmosfet();
  void setnjfet();
  void setpjfet();
  void setdiode();
  void clickbclearcurven();
  void clickbsethintergrund();
  
  void clickcolorhintergrund();
  void clickcolorschrift();
  void clickcolorueberschrift();
  void clickcolorlinie();
  void clickcolorhlinie();
  void clickkurvenstart();
  void clickucplus();
  void clickucminus();
  void clickubplus();
  void clickubminus();
  void clickb10uA();
  void clickb100uA();
  void clickb1mA();
  void clickuc0v();
  void clickuc10v();
  void clickub0v();
  void clickub10v();
  void settabwidget(int);
  void readbfm();
  void grafiksetzen();
  void clickbstrommax();
  void readimax();
  void readakurventimer();
  void readekurventimer();
  void actrepainttimer();
  void clickbdastart();
  void clickaufzeichnung(int);
  void clicksavecsv();
  void aendernboxui1();
  void aendernboxui2(int);
  void aendernIb();
  void fopentty();
  
private:
  QString punkt2komma(QString &);
  void getUI();
  void setUI();
  void createActions();
  void createMenus();
  void createToolBars();
  void createStatusBar();
  void readSettings();
  void writeSettings();
  void defaultlesentty();
  void setKurvenSchreiber();
  void setPolaritaet();
  double getui1const();
  double getui1();
  double getui2const();
  double getui2();
  double getIbconst();
  double getIb();
  void boxui1fuellen();
  void boxui2fuellen();
  void cfgladen();
  void cfgspeichern();
  void warmstart();
   
  double ucdeinnpn;
  double ucdeinpnp;
  double ucdeinnmos;
  double ucdeinpmos;
  double ucdeinnjfet;
  double ucdeinpjfet;
  double udiode;
  double ibausnpn;
  double ibauspnp;
  double ugausnmos;
  double ugauspmos;
  double ugausnjfet;
  double ugauspjfet;
  double imaxnpn;
  double imaxpnp;
  double imaxnmos;
  double imaxpmos;
  double imaxnjfet;
  double imaxpjfet;
  QColor colorhintergrund;
  QColor colorschrift;
  QColor colorueberschrift;
  QColor colorlinie;
  QColor colorhlinie;
  int ueberschriftsize;
  bool kurvenende;

  double ucpol;
  double ubpol;
  int adindex;
  int eecounter;
  int syncounter;
  
  PlotSettings ksettings;
  ehalbleitertyp halbleitertyp;
  ekurventyp kurventyp;
  
  QString version, verdatum;
  QVector<QPointF>  messkurve;
  int rxindex;
  char rxbuffer[4100];
  int kurvennummer;
  QStringList messreihe;
  QStringList listtty;
  int idtty;
  bool bvantwort;
  bool bksgefunden;
  char geraet;
  uchar kversion;

  QTabWidget *awidget;
  QWidget *wkschreiber;
  
  QGroupBox *gkurven;
  QPushButton *bkurvestart;
  QPushButton *bclearcurven;
  QPushButton *bsethintergrund;
  QComboBox *boxui1;
  QLabel *labelui1;
  QComboBox *boxui2;
  QLabel *labelui2;
  QCheckBox *checkclrcurve;
  
  QGroupBox *gibasis;
  QRadioButton *i10ua;
  QRadioButton *i100ua;
  QRadioButton *i1ma;
  
  QTextEdit *textedit;
  
  QWidget *woption;
  
  QGroupBox *gcolor;
  QPushButton *bcolorhintergrund;
  QPushButton *bcolorschrift;
  QPushButton *bcolorueberschrift;
  QPushButton *bcolorlinie;
  QPushButton *bcolorhlinie;

  QGroupBox *gdatei;
  QLineEdit *edateiname;
  QLabel *labeldateiname;
  QSpinBox *sphnr;
  QLabel *labelhnr;
  QCheckBox *checkaufzeichnung;
  
  QWidget *wtest;
  
  QGroupBox *grelais;
  QPushButton *bucplus;
  QPushButton *bucminus;
  QPushButton *bubplus;
  QPushButton *bubminus;
  QPushButton *b10uA;
  QPushButton *b100uA;
  QPushButton *b1mA;
  
  QGroupBox *gspannungen;
  QPushButton *buc0v;
  QPushButton *buc10v;
  QPushButton *bub0v;
  QPushButton *bub10v;
  
  QGroupBox *ganzeige;
  QLabel *ladbasis;
  QLabel *ladcollector;
  QLabel *lademitter;
  QLabel *lubasis;
  QLabel *lucollector;
  QLabel *liemitter;
  
  QGroupBox *gstrommax;
  QSpinBox *spstrommax;
  QLabel *labelspstrommax;
  QPushButton *bstrommax;
  QLabel *lstrommax;
  QLabel *luc;
  
  QGroupBox *gdatest;
  QPushButton *bdastart;
  
  QMenu *fileMenu;
  QMenu *kschreiberMenu;
  QMenu *transistortypMenu;
  QMenu *optionMenu;
  QMenu *helpMenu;
  QToolBar *fileToolBar;
  QAction *exitAct;
  QAction *aboutAct;
  QAction *aboutQtAct;
  QAction *rs232Act;
  QAction *kennlausgangAct;
  QAction *kennleingangAct;
  QAction *npnAct;
  QAction *pnpAct;
  QAction *nmosfetAct;
  QAction *pmosfetAct;
  QAction *njfetAct;
  QAction *pjfetAct;
  QAction *diodeAct;
  QAction *savecsvAct;

  Modem *picmodem;
  QString srs232;
  bool rs232isopen;
  bool bwstart;

  QTimer *testtimer;
  QTimer *imaxtimer;
  QTimer *akurventimer;
  QTimer *ekurventimer;
  QTimer *repainttimer;
  QTimer *openttytimer;
  
  int idlezaehler;
  WDisplay *grafik;
};

#endif

==> kschreiber_v1_12.tar.gz: kschreiber_v1_12/kschreiber.h <==
/***************************************************************************
 *   Copyright (C) 2009 by Andreas Lindenau   *
 *   DL4JAL@darc.de   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/


#ifndef kschreiber_H
#define kschreiber_H

#include <QtGlobal>
#if QT_VERSION >= 0x050000
#include <QtWidgets>
#else
#include <QtGui>
#endif
#include <QtCore>

#include "wdisplay.h"

#ifdef Q_WS_WIN
#include "win_modem.h"
#else
#include "lin_modem.h"
#endif

class QAction;
class QMenu;
class QTabWidget;
class QWidget;
class QTextEdit;
class QComboBox;


class kschreiber:public QMainWindow
{
      Q_OBJECT

public:
  kschreiber();
  ~kschreiber();
public slots:
  void empfmwert(QPointF);

protected:
  void closeEvent(QCloseEvent *event);
  virtual void resizeEvent( QResizeEvent *);
  virtual void repaintEvent( QPaintEvent *);

private slots:
  QString fnamenormal(QString &qs);
  QString datetime2filename();
  void bildspeichern();
  void about();
  void rs232einstellen();
  void setAText(QString);
  void kennlausgang();
  void kennleingang();
  void setnpn();
  void setpnp();
  void setnmosfet();
  void setpmosfet();
  void setnjfet();
  void setpjfet();
  void setdiode();
  void clickbclearcurven();
  void clickbsethintergrund();
  
  void clickcolorhintergrund();
  void clickcolorschrift();
  void clickcolorueberschrift();
  void clickcolorgitter();
  void clickcolorlinie();
  void clickcolorhlinie();
  void clickkurvenstart();
  void clickucplus();
  void clickucminus();
  void clickubplus();
  void clickubminus();
  void clickb10uA();
  void clickb100uA();
  void clickb1mA();
  void clickuc0v();
  void clickuc10v();
  void clickub0v();
  void clickub10v();
  void settabwidget(int);
  void readbfm();
  void grafiksetzen();
  void clickbstrommax();
  void readimax();
  void readakurventimer();
  void readekurventimer();
  void actrepainttimer();
  void clickbdastart();
  void clickaufzeichnung(int);
  void clicksavecsv();
  void aendernboxui1();
  void aendernboxui2(int);
  void aendernIb();
  void fopentty();
  void setlinieFontSize(int);
  void setlFontSize(int);
  void setucvar(int);
  void setubvar(int);
  void labelspeichern();
  void setadcoffset(int);
  void setTextEdit();

private:
  QString punkt2komma(QString &);
  void getUI();
  void setUI();
  void createActions();
  void createMenus();
  void createToolBars();
  void createStatusBar();
  void readSettings();
  void writeSettings();
  void defaultlesentty();
  void setKurvenSchreiber();
  void setPolaritaet();
  double getui1const();
  double getui1();
  double getui2const();
  double getui2();
  double getIbconst();
  double getIb();
  void boxui1fuellen();
  void boxui2fuellen();
  void cfgladen();
  void cfgspeichern();
  void warmstart();
  int adc2int(uchar,uchar);
  void text2info();
   
  double ucdeinnpn;
  double ucdeinpnp;
  double ucdeinnmos;
  double ucdeinpmos;
  double ucdeinnjfet;
  double ucdeinpjfet;
  double udiode;
  double ibausnpn;
  double ibauspnp;
  double ibausdiode;
  double ibeinnpn;
  double ibeinpnp;
  double ibeindiode;
  double ugausnmos;
  double ugauspmos;
  double ugausnjfet;
  double ugauspjfet;
  double imaxnpn;
  double imaxpnp;
  double imaxnmos;
  double imaxpmos;
  double imaxnjfet;
  double imaxpjfet;
  QColor colorhintergrund;
  QColor colorschrift;
  QColor colorueberschrift;
  QColor colorlinie;
  QColor colorgitter;
  QColor colorhlinie;
  int ueberschriftsize;
  bool kurvenende;

  double ucpol;
  double ubpol;
  int adindex;
  int eecounter;
  int syncounter;
  double kadcmax;
  int kadcoffset;
  
  PlotSettings ksettings;
  ekurventyp kurventyp;
  
  QString version, verdatum, infotext;
  QVector<QPointF>  messkurve;
  int rxindex;
  unsigned char rxbuffer[4100];
  int kurvennummer;
  QStringList messreihe;
  QStringList listtty;
  QStringList infomessung;

  int idtty;
  bool bvantwort;
  bool bksgefunden;
  char geraet;


  QTabWidget *awidget;
  QWidget *wkschreiber;
  
  QGroupBox *gkurven;
  QPushButton *bkurvestart;
  QPushButton *bclearcurven;
  QPushButton *bsethintergrund;
  QComboBox *boxui1;
  QLabel *labelui1;
  QComboBox *boxui2;
  QLabel *labelui2;
  QCheckBox *checkclrcurve;

  QGroupBox *gibasis;
  QRadioButton *i10ua;
  QRadioButton *i100ua;
  QRadioButton *i1ma;
  
  QTextEdit *textedit;
  
  QWidget *woption;
  
  QGroupBox *gcolor;
  QPushButton *bcolorhintergrund;
  QPushButton *bcolorschrift;
  QPushButton *bcolorueberschrift;
  QPushButton *bcolorgitter;
  QPushButton *bcolorlinie;
  QPushButton *bcolorhlinie;
  QSpinBox *sboxliniefsize;
  QLabel *labelliniefsize;
  QSpinBox *sboxliniesize;
  QLabel *labelliniesize;

  QGroupBox *gdatei;
  QLineEdit *edateiname;
  QLabel *labeldateiname;
  QSpinBox *sphnr;
  QLabel *labelhnr;
  QCheckBox *checkaufzeichnung;
  
  QWidget *wtest;
  
  QGroupBox *grelais;
  QPushButton *bucplus;
  QPushButton *bucminus;
  QPushButton *bubplus;
  QPushButton *bubminus;
  QPushButton *b10uA;
  QPushButton *b100uA;
  QPushButton *b1mA;
  
  QGroupBox *gspannungen;
  QPushButton *buc0v;
  QPushButton *buc10v;
  QPushButton *bub0v;
  QPushButton *bub10v;
  QSpinBox *spucvar;
  QSpinBox *spubvar;
  QLabel *lucvar;
  QLabel *lubvar;

  QGroupBox *ganzeige;
  QLabel *ladbasis;
  QLabel *ladcollector;
  QLabel *lademitter;
  QLabel *lubasis;
  QLabel *lucollector;
  QLabel *liemitter;
  QSpinBox *spadcoffset;
  QLabel *ladcoffset;

  QGroupBox *gstrommax;
  QSpinBox *spstrommax;
  QLabel *labelspstrommax;
  QPushButton *bstrommax;
  QLabel *lstrommax;
  QLabel *luc;
  
  QGroupBox *gdatest;
  QPushButton *bdastart;

  QMenu *fileMenu;
  QMenu *kschreiberMenu;
  QMenu *transistortypMenu;
  QMenu *optionMenu;
  QMenu *helpMenu;
  QToolBar *fileToolBar;
  QAction *exitAct;
  QAction *aboutAct;
  QAction *aboutQtAct;
  QAction *rs232Act;
  QAction *kennlausgangAct;
  QAction *kennleingangAct;
  QAction *npnAct;
  QAction *pnpAct;
  QAction *nmosfetAct;
  QAction *pmosfetAct;
  QAction *njfetAct;
  QAction *pjfetAct;
  QAction *diodeAct;
  QAction *savecsvAct;
  QAction *savegrafikAct;
  QAction *labelAct;

  Modem *picmodem;
  QString srs232;
  bool rs232isopen;
  bool bwstart;

  QTimer *testtimer;
  QTimer *imaxtimer;
  QTimer *akurventimer;
  QTimer *ekurventimer;
  QTimer *repainttimer;
  QTimer *openttytimer;
  
  int idlezaehler;
  WDisplay *grafik;

signals:
  void dbildspeichern(QString);

};

#endif
